sqlalchemy\_authorize package
=============================

Subpackages
-----------

.. toctree::

    sqlalchemy_authorize.oso

Submodules
----------

sqlalchemy\_authorize.constants module
--------------------------------------

.. automodule:: sqlalchemy_authorize.constants
    :members:
    :undoc-members:
    :show-inheritance:

sqlalchemy\_authorize.permissions\_mixin module
-----------------------------------------------

.. automodule:: sqlalchemy_authorize.permissions_mixin
    :members:
    :undoc-members:
    :show-inheritance:

sqlalchemy\_authorize.utils module
----------------------------------

.. automodule:: sqlalchemy_authorize.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: sqlalchemy_authorize
    :members:
    :undoc-members:
    :show-inheritance:
